from __future__ import absolute_import, division, print_function, unicode_literals


ASSET_MANAGER_TYPES = {'Accredited Investor', 'Bank', 'Broker', 'Corporate Treasury', 'Family Office',
                       'Fund Administrator', 'Fund Manager', 'Hedge Fund', 'Private Equity', 'Retail',
                       'Venture Capital'}
RELATIONSHIP_TYPES = {'Administrator', 'External', 'Front Office', 'Employee'}
